DropDialogRouteBuilder class abstract
Метод сборщик позиционного диалогого окна для нового роута
CustomRoute(
path: 'test',
page: TestRoute.page,
customRouteBuilder: DropDialogRouteBuilder.builder,
),
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
builder<
T> (BuildContext context, Widget child, AutoRoutePage< T> page) → Route<T>